@@ -6,8 +6,8 @@
 ;; Keywords: processes, tools
 ;; Homepage: https://github.com/purcell/envrc
 ;; Package-Requires: ((emacs "27.1") (inheritenv "0.1") (seq "2.24"))
-;; Package-Version: 20250917.915
-;; Package-Revision: de1ae6e53876
+;; Package-Version: 20260209.1350
+;; Package-Revision: d3289e92e0e2
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -162,7 +162,8 @@ e.g. (define-key envrc-mode-map (kbd \"C-c e\") \\='envrc-command-map)"
                 envrc-supported-tramp-methods
                 (with-parsed-tramp-file-name default-directory vec vec-method))))
          (t (executable-find envrc-direnv-executable)))
-      (envrc-mode 1))))
+      (envrc-mode 1)))
+  :predicate t)
 
 (defface envrc-mode-line-on-face '((t :inherit success))
   "Face used in mode line to indicate that direnv is in effect.")
